import React from "react";
import { FormControl, FormHelperText, InputLabel, MenuItem, Select, withStyles } from "@material-ui/core";
import clsx from "clsx";
import { getErrorMessages, getErrorsForPointer } from "../EditorErrorMessages";
export var styles = {
    root: {
        width: "100%"
    },
    selectTitle: {
        display: "block",
        fontSize: "14px",
        textTransform: "uppercase",
        padding: 16,
        fontWeight: 500
    }
};
var EditorDropdownField = function (props) {
    var schema = props.schema, value = props.value, readonly = props.readonly, required = props.required, disabled = props.disabled, onChange = props.onChange, classes = props.classes, pointer = props.pointer, errorReport = props.errorReport, registry = props.registry;
    var handleChange = React.useCallback(function (event) {
        var newValue = event.target.value;
        if (onChange) {
            onChange(newValue);
        }
    }, [onChange]);
    var errors = getErrorsForPointer(pointer, errorReport);
    var errorMessages = getErrorMessages(schema, errors, registry);
    var enumValues = schema.enum || [];
    return (React.createElement(FormControl, { className: classes.root },
        React.createElement(InputLabel, { required: required }, schema.title || ""),
        React.createElement(Select, { autoWidth: true, disabled: disabled, onChange: handleChange, inputProps: {
                readOnly: readonly,
                "aria-label": schema.description || ""
            }, error: errorMessages.length > 0, value: value },
            React.createElement(InputLabel, { className: clsx(classes.selectTitle) }, schema.title || ""),
            React.createElement(MenuItem, { value: undefined }, "None"),
            enumValues.map(function (enumValue) { return (React.createElement(MenuItem, { key: enumValue, value: enumValue }, "" + enumValue)); })),
        React.createElement(FormHelperText, { error: errorMessages.length > 0 }, errorMessages.length ? errorMessages[0] : schema.description)));
};
export default withStyles(styles, { name: "DcEditorDropdownField" })(EditorDropdownField);
